@@ -3,7 +3,7 @@
  *  Module    : extern.h
  *  Author    : I. Lea
  *  Created   : 1991-04-01
- *  Updated   : 2015-11-21
+ *  Updated   : 2016-06-06
  *  Notes     :
  *
  * Copyright (c) 1997-2016 Iain Lea <iain@bricbrac.de>
@@ -479,6 +479,9 @@ extern constext txt_articles_mailed[];
 #ifndef DISABLE_PRINTING
 	extern constext txt_articles_printed[];
 #endif /* !DISABLE_PRINTING */
+#ifndef DONT_HAVE_PIPING
+	extern constext txt_articles_piped[];
+#endif /* !DONT_HAVE_PIPING */
 extern constext txt_attach[];
 extern constext txt_attach_charset[];
 extern constext txt_attach_description[];
@@ -904,6 +907,10 @@ extern constext txt_help_select_goto_group[];
 extern constext txt_help_select_group_by_num[];
 extern constext txt_help_select_group_range[];
 extern constext txt_help_select_last_group[];
+#ifdef NNTP_ABLE
+	extern constext txt_help_select_lookup_group[];
+	extern constext txt_help_select_lookup_group_comment[];
+#endif /* NNTP_ABLE */
 extern constext txt_help_select_mark_group_unread[];
 extern constext txt_help_select_move_group[];
 extern constext txt_help_select_next_unread_group[];
@@ -987,6 +994,12 @@ extern constext txt_kill_time[];
 extern constext txt_last[];
 extern constext txt_last_resp[];
 extern constext txt_lines[];
+#ifdef NNTP_ABLE
+	extern constext txt_lookup_func_not_available[];
+	extern constext txt_lookup_func_not_nntp[];
+	extern constext txt_lookup_show_group[];
+	extern constext txt_lookup_show_groups[];
+#endif /* NNTP_ABLE */
 extern constext txt_mail[];
 extern constext txt_mailbox[];
 extern constext txt_mail_art_to[];
@@ -1800,7 +1813,9 @@ extern struct opttxt txt_sort_threads_type;
 extern struct opttxt txt_spamtrap_warning_addresses;
 extern struct opttxt txt_stars_regex;
 extern struct opttxt txt_start_editor_offset;
-extern struct opttxt txt_strip_blanks;
+#ifndef USE_CURSES
+	extern struct opttxt txt_strip_blanks;
+#endif /* !USE_CURSES */
 extern struct opttxt txt_strip_bogus;
 extern struct opttxt txt_strip_newsrc;
 extern struct opttxt txt_strip_re_regex;
